@@ -6,6 +6,7 @@ import pytest
 
 import narwhals as nw
 from tests.utils import (
+    DUCKDB_VERSION,
     PANDAS_VERSION,
     Constructor,
     ConstructorEager,
@@ -138,10 +139,8 @@ def test_offset_by(
     by: str,
     expected: list[datetime],
 ) -> None:
-    df = nw.from_native(constructor(data))
-    if df.implementation.is_pyspark_connect():
-        # missing feature upstream
-        request.applymarker(pytest.mark.xfail())
+    if "duckdb" in str(constructor) and DUCKDB_VERSION < (1, 3):
+        pytest.skip()
     if any(x in by for x in ("y", "q", "mo")) and any(
         x in str(constructor) for x in ("dask", "pyarrow", "ibis")
     ):
@@ -152,6 +151,8 @@ def test_offset_by(
         request.applymarker(pytest.mark.xfail())
     if by.endswith("d") and any(x in str(constructor) for x in ("dask", "ibis")):
         request.applymarker(pytest.mark.xfail())
+
+    df = nw.from_native(constructor(data))
     result = df.select(nw.col("a").dt.offset_by(by))
     assert_equal_data(result, {"a": expected})
 
@@ -241,6 +242,8 @@ def test_offset_by_series(constructor_eager: ConstructorEager) -> None:
 
 
 def test_offset_by_invalid_interval(constructor: Constructor) -> None:
+    if "duckdb" in str(constructor) and DUCKDB_VERSION < (1, 3):
+        pytest.skip()
     df = nw.from_native(constructor(data))
     msg = "Invalid `every` string"
     with pytest.raises(ValueError, match=msg):
@@ -261,3 +264,20 @@ def test_offset_by_date_pandas() -> None:
     result = df.select(nw.col("a").dt.offset_by("1d"))
     expected = {"a": [date(2020, 1, 2)]}
     assert_equal_data(result, expected)
+
+
+def test_offset_by_3471(constructor: Constructor, request: pytest.FixtureRequest) -> None:
+    if any(x in str(constructor) for x in ("dask", "ibis")):
+        request.applymarker(pytest.mark.xfail())
+    if "duckdb" in str(constructor) and DUCKDB_VERSION < (1, 3):
+        pytest.skip()
+    date_nw = nw.from_native(constructor({"date": [date(2026, 1, 31)]}))
+
+    existent_col_offset = nw.col("date").dt.offset_by("-1d")
+    result = date_nw.with_columns(existent_col_offset)
+    expected = {"date": [datetime(2026, 1, 30)]}
+    assert_equal_data(result, expected)
+
+    new_lit_offset = nw.lit(datetime(2026, 1, 31)).dt.offset_by("-1d")
+    result = date_nw.with_columns(date=new_lit_offset)
+    assert_equal_data(result, expected)
