@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from datetime import date, datetime, time, timedelta
+from datetime import date, datetime, time, timedelta, timezone
 from typing import TYPE_CHECKING
 
 import pytest
@@ -22,6 +22,7 @@ def testing_schema() -> IntoSchema:
         "enum": nw.Enum(["beluga", "narwhal", "orca"]),
         "bool": nw.Boolean(),
         "datetime": nw.Datetime(),
+        "datetime_tz": nw.Datetime(time_zone="UTC"),
         "date": nw.Date(),
         "time": nw.Time(),
         "duration": nw.Duration(),
@@ -47,6 +48,12 @@ def testing_data() -> Data:
             datetime(2025, 1, 3, 12),
             None,
         ],
+        "datetime_tz": [
+            datetime(2025, 1, 1, 12, tzinfo=timezone.utc),
+            datetime(2025, 1, 2, 12, tzinfo=timezone.utc),
+            datetime(2025, 1, 3, 12, tzinfo=timezone.utc),
+            None,
+        ],
         "date": [date(2025, 1, 1), date(2025, 1, 2), date(2025, 1, 3), None],
         "time": [time(9, 0), time(9, 1, 10), time(9, 2), None],
         "duration": [
