@@ -98,7 +98,7 @@ def assert_equal_data(result: Any, expected: Mapping[str, Any]) -> None:
     )
     if is_duckdb:
         result = from_native(result.collect("pyarrow"))
-    if is_ibis:
+    if is_ibis:  # pragma: no cover
         result = from_native(result.to_native().to_pyarrow())
     if hasattr(result, "collect"):
         kwargs: dict[Implementation, dict[str, Any]] = {Implementation.POLARS: {}}
@@ -166,6 +166,14 @@ def assert_equal_series(
     assert_equal_data(result.to_frame(), {name: expected})
 
 
+def assert_equal_hash(left: Any, right: Any) -> None:
+    """Assert that left and right produce identical hash values."""
+    __tracebackhide__ = True
+    assert left in {right}, (  # noqa: FURB171
+        f"inputs do not compare equal by `__hash__`\n[left]: {left}\n[right]: {right}"
+    )
+
+
 def sqlframe_session() -> DuckDBSession:
     from sqlframe.duckdb import DuckDBSession
 
@@ -193,7 +201,7 @@ def pyspark_session() -> SparkSession:  # pragma: no cover
     )
 
 
-def maybe_get_modin_df(df_pandas: pd.DataFrame) -> Any:
+def maybe_get_modin_df(df_pandas: pd.DataFrame) -> Any:  # pragma: no cover
     """Convert a pandas DataFrame to a Modin DataFrame if Modin is available."""
     try:
         import modin.pandas as mpd
